import express from 'express';
import { create, login, logout, checkin, checkout, takeBreakHandler, returnFromBreakHandler, getUserWork } from '../controllers/UserController';
import { isValidCreateUser, isValidLogin } from '../middlewares/usersResourceValidation';
import { authenticateToken } from '../middlewares/checkAuth';

const userRouter = express.Router();

userRouter.post('/', isValidCreateUser, create);
userRouter.post('/login', isValidLogin, login);
userRouter.post('/logout', logout);

userRouter.post('/checkin', authenticateToken, checkin);
userRouter.post('/checkout', authenticateToken, checkout);

userRouter.post('/breaktime', authenticateToken, takeBreakHandler);
userRouter.post('/returnfrombreak', authenticateToken, returnFromBreakHandler);

userRouter.get('/work', authenticateToken, getUserWork);


export default userRouter;