import mongoose, { Schema, Document } from 'mongoose';

interface IWork extends Document {
  userId: mongoose.Types.ObjectId;
  startTime: Date;
  endTime?: Date;
  isBreak: boolean;
  breakStartTime?: Date;
  breakEndTime?: Date;
  breakDuration?: Number;
  createdAt: Date;
  updatedAt: Date;
}

const workSchema: Schema = new Schema({
  userId: { type: mongoose.Types.ObjectId, ref: 'User', required: true },
  startTime: { type: Date, required: true },
  endTime: { type: Date },
  isBreak: { type: Boolean, default: false },
  breakStartTime: { type: Date },
  breakEndTime: { type: Date },
  breakDuration: { type: Number, default: 0 },
  createdAt: { type: Date, default: Date.now },
  updatedAt: { type: Date, default: Date.now },
});

const Work = mongoose.model<IWork>('Work', workSchema);

export {
  Work,
  IWork
}
